@@ -35,11 +35,11 @@
 #include "imagelib/kpColor.h"
 #include "kpDefs.h"
 
-#include <math.h>
+#include <cmath>
 
-#include <qpainter.h>
-#include <qpixmap.h>
-#include <qpolygon.h>
+#include <QPainter>
+#include <QPixmap>
+#include <QPolygon>
 
 #include "kpLogCategories.h"
 
@@ -47,10 +47,10 @@
 
 // public static
 const double kpColorSimilarityHolder::ColorCubeDiagonalDistance =
-    sqrt ((double)255 * 255 * 3);
+    std::sqrt (255.0 * 255 * 3);
 
 // public static
-const double kpColorSimilarityHolder::MaxColorSimilarity = .30;
+const double kpColorSimilarityHolder::MaxColorSimilarity = 0.30;
 
 
 kpColorSimilarityHolder::kpColorSimilarityHolder ()
@@ -58,9 +58,7 @@ kpColorSimilarityHolder::kpColorSimilarityHolder ()
 {
 }
 
-kpColorSimilarityHolder::~kpColorSimilarityHolder ()
-{
-}
+kpColorSimilarityHolder::~kpColorSimilarityHolder () = default;
 
 
 // Don't cause the translators grief by appending strings etc.
@@ -177,13 +175,16 @@ void kpColorSimilarityHolder::setColorSimilarity (double similarity)
     qCDebug(kpLogWidgets) << "kpColorSimilarityHolder::setColorSimilarity(" << similarity << ")";
 #endif
 
-    if (m_colorSimilarity == similarity)
+    if (m_colorSimilarity == similarity) {
         return;
+    }
 
-    if (similarity < 0)
+    if (similarity < 0) {
         similarity = 0;
-    else if (similarity > MaxColorSimilarity)
+    }
+    else if (similarity > MaxColorSimilarity) {
         similarity = MaxColorSimilarity;
+    }
 
     m_colorSimilarity = similarity;
 }
